import typing
import collections.abc
from .bits import ClauseBit

T = typing.TypeVar("T")

NotationParser = typing.Callable[
    [str | collections.abc.Mapping[str, str]],
    collections.abc.Iterable[tuple[str, ClauseBit]]
]



from .bits import (
    ClauseBit,
    FilterBit,
    EQ,
    NE,
    LE,
    GE,
    LT,
    GT,
    LIKE,
    IS,
    NOT,
    RANGE,
    SET,
    OrderBit,
    ASC,
    DESC,
    SliceBit,
    Limit,
    Offset
)
from .parsing import (
    NotationParser
)
